# Install

You can install ragas with
```bash
pip install ragas
```

If you want to install the latest version (from the main branch)
```bash
pip install git+https://github.com/explodinggradients/ragas.git
```

If you are looking to contribute and make changes to the code, make sure you
clone the repo and install it as [editable
install](https://pip.pypa.io/en/stable/topics/local-project-installs/#editable-installs).
```bash
git clone https://github.com/explodinggradients/ragas.git 
cd ragas 
pip install -e .
```
